@@ -1,4 +1,5 @@
 from .data import Data
+from .temporal import TemporalData
 from .batch import Batch
 from .dataset import Dataset
 from .in_memory_dataset import InMemoryDataset
@@ -7,11 +8,13 @@ from .sampler import NeighborSampler, RandomNodeSampler
 from .cluster import ClusterData, ClusterLoader
 from .graph_saint import (GraphSAINTSampler, GraphSAINTNodeSampler,
                           GraphSAINTEdgeSampler, GraphSAINTRandomWalkSampler)
+from .shadow import ShaDowKHopSampler
 from .download import download_url
 from .extract import extract_tar, extract_zip, extract_bz2, extract_gz
 
 __all__ = [
     'Data',
+    'TemporalData',
     'Batch',
     'Dataset',
     'InMemoryDataset',
@@ -26,6 +29,7 @@ __all__ = [
     'GraphSAINTNodeSampler',
     'GraphSAINTEdgeSampler',
     'GraphSAINTRandomWalkSampler',
+    'ShaDowKHopSampler',
     'download_url',
     'extract_tar',
     'extract_zip',
