@@ -167,12 +167,12 @@ class Data(object):
             if the batch concatenation process is corrupted for a specific data
             attribute.
         """
-        # Concatenate `*index*` and `*face*` attributes in the last dimension.
-        if bool(re.search('(index|face)', key)):
-            return -1
         # By default, concatenate sparse matrices diagonally.
-        elif isinstance(value, SparseTensor):
+        if isinstance(value, SparseTensor):
             return (0, 1)
+        # Concatenate `*index*` and `*face*` attributes in the last dimension.
+        elif bool(re.search('(index|face)', key)):
+            return -1
         return 0
 
     def __inc__(self, key, value):
@@ -209,7 +209,10 @@ class Data(object):
         if hasattr(self, '__num_nodes__'):
             return self.__num_nodes__
         for key, item in self('x', 'pos', 'normal', 'batch'):
-            return item.size(self.__cat_dim__(key, item))
+            if isinstance(item, SparseTensor):
+                return item.size(0)
+            else:
+                return item.size(self.__cat_dim__(key, item))
         if hasattr(self, 'adj'):
             return self.adj.size(0)
         if hasattr(self, 'adj_t'):
@@ -228,7 +231,11 @@ class Data(object):
 
     @property
     def num_edges(self):
-        r"""Returns the number of edges in the graph."""
+        """
+        Returns the number of edges in the graph.
+        For undirected graphs, this will return the number of bi-directional
+        edges, which is double the amount of unique edges.
+        """
         for key, item in self('edge_index', 'edge_attr'):
             return item.size(self.__cat_dim__(key, item))
         for key, item in self('adj', 'adj_t'):
@@ -332,12 +339,32 @@ class Data(object):
         attributes."""
         return self.apply(lambda x: x.to(device, **kwargs), *keys)
 
+    def cpu(self, *keys):
+        r"""Copies all attributes :obj:`*keys` to CPU memory.
+        If :obj:`*keys` is not given, the conversion is applied to all present
+        attributes."""
+        return self.apply(lambda x: x.cpu(), *keys)
+
+    def cuda(self, device=None, non_blocking=False, *keys):
+        r"""Copies all attributes :obj:`*keys` to CUDA memory.
+        If :obj:`*keys` is not given, the conversion is applied to all present
+        attributes."""
+        return self.apply(
+            lambda x: x.cuda(device=device, non_blocking=non_blocking), *keys)
+
     def clone(self):
+        r"""Performs a deep-copy of the data object."""
         return self.__class__.from_dict({
             k: v.clone() if torch.is_tensor(v) else copy.deepcopy(v)
             for k, v in self.__dict__.items()
         })
 
+    def pin_memory(self, *keys):
+        r"""Copies all attributes :obj:`*keys` to pinned memory.
+        If :obj:`*keys` is not given, the conversion is applied to all present
+        attributes."""
+        return self.apply(lambda x: x.pin_memory(), *keys)
+
     def debug(self):
         if self.edge_index is not None:
             if self.edge_index.dtype != torch.long:
