@@ -1,3 +1,4 @@
+from .sequential import Sequential
 from .meta import MetaLayer
 from .data_parallel import DataParallel
 from .reshape import Reshape
@@ -8,8 +9,11 @@ from .pool import *  # noqa
 from .unpool import *  # noqa
 from .dense import *  # noqa
 from .models import *  # noqa
+from .functional import *  # noqa
+
 
 __all__ = [
+    'Sequential',
     'MetaLayer',
     'DataParallel',
     'Reshape',
