@@ -41,7 +41,8 @@ class FeaStConv(MessagePassing):
     """
     def __init__(self, in_channels: int, out_channels: int, heads: int = 1,
                  add_self_loops: bool = True, bias: bool = True, **kwargs):
-        super(FeaStConv, self).__init__(aggr='mean', **kwargs)
+        kwargs.setdefault('aggr', 'mean')
+        super(FeaStConv, self).__init__(**kwargs)
 
         self.in_channels = in_channels
         self.out_channels = out_channels
