@@ -30,6 +30,13 @@ class GMMConv(MessagePassing):
     :math:`\mathbf{\mu}_k` and diagonal covariance matrix
     :math:`\mathbf{\Sigma}_k`.
 
+    .. note::
+
+        The edge attribute :math:`\mathbf{e}_{ij}` is usually given by
+        :math:`\mathbf{e}_{ij} = \mathbf{p}_j - \mathbf{p}_i`, where
+        :math:`\mathbf{p}_i` denotes the position of node :math:`i` (see
+        :class:`torch_geometric.transform.Cartesian`).
+
     Args:
         in_channels (int or tuple): Size of each input sample. A tuple
             corresponds to the sizes of source and target dimensionalities.
