@@ -10,6 +10,10 @@ from .dimenet import DimeNet
 from .gnn_explainer import GNNExplainer
 from .metapath2vec import MetaPath2Vec
 from .deepgcn import DeepGCNLayer
+from .tgn import TGNMemory
+from .label_prop import LabelPropagation
+from .correct_and_smooth import CorrectAndSmooth
+from .attentive_fp import AttentiveFP
 
 __all__ = [
     'JumpingKnowledge',
@@ -28,6 +32,10 @@ __all__ = [
     'GNNExplainer',
     'MetaPath2Vec',
     'DeepGCNLayer',
+    'TGNMemory',
+    'LabelPropagation',
+    'CorrectAndSmooth',
+    'AttentiveFP',
 ]
 
 classes = sorted(__all__)
