@@ -3,7 +3,6 @@ import warnings
 import os.path as osp
 from math import pi as PI
 
-import ase
 import torch
 import torch.nn.functional as F
 from torch.nn import Embedding, Sequential, Linear, ModuleList
@@ -14,6 +13,11 @@ from torch_geometric.data.makedirs import makedirs
 from torch_geometric.data import download_url, extract_zip
 from torch_geometric.nn import radius_graph, MessagePassing
 
+try:
+    import ase
+except ImportError:
+    ase = None
+
 try:
     import schnetpack as spk
 except ImportError:
@@ -89,6 +93,9 @@ class SchNet(torch.nn.Module):
                  atomref=None):
         super(SchNet, self).__init__()
 
+        if ase is None:
+            raise ImportError('Package `ase` could not be found.')
+
         assert readout in ['add', 'sum', 'mean']
 
         self.hidden_channels = hidden_channels
@@ -140,6 +147,8 @@ class SchNet(torch.nn.Module):
 
     @staticmethod
     def from_qm9_pretrained(root, dataset, target):
+        if ase is None:
+            raise ImportError('Package `ase` could not be found.')
         if spk is None:
             raise ImportError(
                 '`SchNet.from_qm9_pretrained` requires `schnetpack`.')
