@@ -2,6 +2,7 @@ from typing import Optional
 
 from torch_scatter import scatter
 from torch_geometric.data import Batch
+from torch_geometric.utils import add_self_loops
 
 from .consecutive import consecutive_cluster
 from .pool import pool_edge, pool_batch, pool_pos
@@ -75,3 +76,19 @@ def max_pool(cluster, data, transform=None):
         data = transform(data)
 
     return data
+
+
+def max_pool_neighbor_x(data, flow='source_to_target'):
+    r"""Max pools neighboring node features, where each feature in
+    :obj:`data.x` is replaced by the feature value with the maximum value from
+    the central node and its neighbors.
+    """
+    x, edge_index = data.x, data.edge_index
+
+    edge_index, _ = add_self_loops(edge_index, num_nodes=data.num_nodes)
+
+    row, col = edge_index
+    row, col = (row, col) if flow == 'source_to_target' else (col, row)
+
+    data.x = scatter(x[row], col, dim=0, dim_size=data.num_nodes, reduce='max')
+    return data
