@@ -8,22 +8,29 @@ class LocalCartesian(object):
     interval :math:`{[0, 1]}^D`.
 
     Args:
+        norm (bool, optional): If set to :obj:`False`, the output will not be
+            normalized to the interval :math:`{[0, 1]}^D`.
+            (default: :obj:`True`)
         cat (bool, optional): If set to :obj:`False`, all existing edge
             attributes will be replaced. (default: :obj:`True`)
     """
-
-    def __init__(self, cat=True):
+    def __init__(self, norm=True, cat=True):
+        self.norm = norm
         self.cat = cat
 
     def __call__(self, data):
         (row, col), pos, pseudo = data.edge_index, data.pos, data.edge_attr
 
-        cart = pos[col] - pos[row]
+        cart = pos[row] - pos[col]
         cart = cart.view(-1, 1) if cart.dim() == 1 else cart
 
-        max_value, _ = scatter_max(cart.abs(), row, 0, dim_size=pos.size(0))
+        max_value, _ = scatter_max(cart.abs(), col, 0, dim_size=pos.size(0))
         max_value = max_value.max(dim=-1, keepdim=True)[0]
-        cart = cart / (2 * max_value[row]) + 0.5
+
+        if self.norm:
+            cart = cart / (2 * max_value[col]) + 0.5
+        else:
+            cart = cart / max_value[col]
 
         if pseudo is not None and self.cat:
             pseudo = pseudo.view(-1, 1) if pseudo.dim() == 1 else pseudo
