@@ -3,19 +3,20 @@ import torch.nn.functional as F
 
 
 class NormalizeRotation(object):
-    r"""Rotates all points so that the eigenvectors overlie the axes of the
-    Cartesian coordinate system.
-    If the data additionally holds normals saved in :obj:`data.norm` these will
-    be also rotated.
+    r"""Rotates all points according to the eigenvectors of the point cloud.
+    If the data additionally holds normals saved in :obj:`data.normal`, these
+    will be rotated accordingly.
 
     Args:
         max_points (int, optional): If set to a value greater than :obj:`0`,
             only a random number of :obj:`max_points` points are sampled and
             used to compute eigenvectors. (default: :obj:`-1`)
+        sort (bool, optional): If set to :obj:`True`, will sort eigenvectors
+            according to their eigenvalues. (default: :obj:`False`)
     """
-
-    def __init__(self, max_points=-1):
+    def __init__(self, max_points: int = -1, sort: bool = False):
         self.max_points = max_points
+        self.sort = sort
 
     def __call__(self, data):
         pos = data.pos
@@ -28,10 +29,14 @@ class NormalizeRotation(object):
         C = torch.matmul(pos.t(), pos)
         e, v = torch.eig(C, eigenvectors=True)  # v[:,j] is j-th eigenvector
 
+        if self.sort:
+            indices = e[:, 0].argsort(descending=True)
+            v = v.t()[indices].t()
+
         data.pos = torch.matmul(data.pos, v)
 
-        if 'norm' in data:
-            data.norm = F.normalize(torch.matmul(data.norm, v))
+        if 'normal' in data:
+            data.normal = F.normalize(torch.matmul(data.normal, v))
 
         return data
 
