@@ -21,7 +21,7 @@ class SamplePoints(object):
         pos, face = data.pos, data.face
         assert pos.size(1) == 3 and face.size(0) == 3
 
-        pos_max = pos.max()
+        pos_max = pos.abs().max()
         pos = pos / pos_max
 
         area = (pos[face[1]] - pos[face[0]]).cross(pos[face[2]] - pos[face[0]])
