@@ -2,11 +2,6 @@ import torch
 from torch_scatter import scatter_mean
 from torch_geometric.data import Data
 
-try:
-    from skimage.segmentation import slic
-except ImportError:
-    slic = None
-
 
 class ToSLIC(object):
     r"""Converts an image to a superpixel representation using the
@@ -36,15 +31,13 @@ class ToSLIC(object):
             #skimage.segmentation.slic>`_ for an overview.
     """
     def __init__(self, add_seg=False, add_img=False, **kwargs):
-
-        if slic is None:
-            raise ImportError('`ToSlic` requires `scikit-image`.')
-
         self.add_seg = add_seg
         self.add_img = add_img
         self.kwargs = kwargs
 
     def __call__(self, img):
+        from skimage.segmentation import slic
+
         img = img.permute(1, 2, 0)
         h, w, c = img.size()
 
